mdt.gui.model_fit.design package
================================

Submodules
----------

mdt.gui.model_fit.design.main_gui_rc module
-------------------------------------------

.. automodule:: mdt.gui.model_fit.design.main_gui_rc
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_about_dialog module
-----------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_about_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_fit_model_tab module
------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_fit_model_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_generate_brain_mask_tab module
----------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_brain_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_generate_protocol_load_gb_dialog module
-------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_protocol_load_gb_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_generate_protocol_tab module
--------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_protocol_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_generate_protocol_update_dialog module
------------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_protocol_update_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_generate_roi_mask_tab module
--------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_generate_roi_mask_tab
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_main_gui module
-------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_main_gui
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_optimization_options_dialog module
--------------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_optimization_options_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_runtime_settings_dialog module
----------------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_runtime_settings_dialog
    :members:
    :undoc-members:
    :show-inheritance:

mdt.gui.model_fit.design.ui_view_results_tab module
---------------------------------------------------

.. automodule:: mdt.gui.model_fit.design.ui_view_results_tab
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mdt.gui.model_fit.design
    :members:
    :undoc-members:
    :show-inheritance:
